@@ -242,7 +242,7 @@ class Option(FContainer['Option[T]', T], Monad['Option[T]', T], Functor['Option[
             f: `Callable[[T], R]`. A function of signature `(T) -> R` that is applied to the non-empty options.
         """
         
-        self.map(f)
+        for v in self: f(v)
     #endregion
     
     #region Operators
